@@ -450,10 +450,20 @@ class Microservices(BaseClass, ABC):
             currDate = datetime.datetime.utcnow()
 
             if IS_Z:
-                DATE = datetime.datetime.strptime(
-                    TIME,
-                    '%Y-%m-%dT%H:%M:%SZ'
+                include_mil = re.search(
+                    r"\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d{1,}z",
+                    TIME
                 )
+                if include_mil:
+                    DATE = datetime.datetime.strptime(
+                        TIME,
+                        '%Y-%m-%dT%H:%M:%S.%fZ'
+                    )
+                else:
+                    DATE = datetime.datetime.strptime(
+                        TIME,
+                        '%Y-%m-%dT%H:%M:%SZ'
+                    )
 
                 elapsedTime = currDate - DATE
                 diff = divmod(elapsedTime.total_seconds(), 60)[0]
